#!/usr/bin/env python
# -*- coding:UTF-8 -*-

import requests
import json
from HTMLParser import HTMLParser

class Google_Translate(object):
    '''
    English            : en
    Chinese Simplified : zh-CN
    '''
    
    def __init__(self):
        self.baseUrl = "https://www.googleapis.com/language/translate/v2"
        self.FORMATS = ('text', 'html')
        self.params = {}
        
    def setParams(self, key, source_lang, target_lang, trans_text, format = 'text'):
        ''' set query parameters
            key          --the api key (required)
            source_lang  --source language  (optional)
            target_lang  --target language  (required)
            text         --translate text and text may be either a string or a list of strings(required)
            format       -- optional'''
        
        text_parser = HTMLParser()
        for _index in range(len(trans_text)):
            trans_text[_index] = text_parser.unescape(trans_text[_index])
        # text = text_parser.unescape(trans_text)
        if format not in self.FORMATS:
            raise TypeError('The format should be one of %s' % (self.FORMATS))
        
        params = {'key': key,
                  'source': source_lang,
                  'target': target_lang,
                  'format': format,
                  'q': trans_text,
                  }
        self.params.update(params)

    def translate(self):
        url = self.baseUrl
        try:
            r = requests.get(url, params = self.params, timeout = 20)
        except Exception as e:
            return {'ret':False, 'msg':str(e)}
        if not r.ok:
            return {'ret':False,'msg':r.text}
        try:
            result_var = json.loads(r.text)
        except:
            return {'ret':False,'msg':r.text}
        result = result_var['data']['translations']
        return {'ret':True, 'data':result}

